#
# spec file for package python-limnoria
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define appname limnoria
%define srcver 2020-05-01
Name:           python-limnoria
Version:        2020.05.01
Release:        lp151.2.3.1
Summary:        A modified version of Supybot (an IRC bot and framework)
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ProgVal/Limnoria
Source:         https://github.com/ProgVal/Limnoria/archive/master-%{srcver}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module PySocks}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module ecdsa}
BuildRequires:  %{python_module feedparser}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module python-gnupg}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PySocks
Requires:       python-SQLAlchemy
Requires:       python-chardet
Requires:       python-ecdsa
Requires:       python-feedparser
Requires:       python-python-dateutil
Requires:       python-python-gnupg
Requires:       python-pytz
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       Supybot = %{version}
Obsoletes:      Supybot < 1.0
BuildArch:      noarch
%python_subpackages

%description
Limnoria is a Python IRC bot with a plugin API. It is equipped with
an ACL system for specifying user permissions with per-command
granularity. Numerous plugins are included.

%prep
%setup -q -n Limnoria-master-%{srcver}
sed -i "1,4{/\/usr\/bin\/python/d}" plugins/Debug/plugin.py
sed -i "1,4{/\/usr\/bin\/env/d}" plugins/SedRegex/constants.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/supybot/
%python_clone -a %{buildroot}%{_mandir}/man1/supybot.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-adduser.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-botchk.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-plugin-create.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-plugin-doc.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-test.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-wizard.1
%python_clone -a %{buildroot}%{_bindir}/supybot
%python_clone -a %{buildroot}%{_bindir}/supybot-adduser
%python_clone -a %{buildroot}%{_bindir}/supybot-botchk
%python_clone -a %{buildroot}%{_bindir}/supybot-plugin-create
%python_clone -a %{buildroot}%{_bindir}/supybot-plugin-doc
%python_clone -a %{buildroot}%{_bindir}/supybot-reset-password
%python_clone -a %{buildroot}%{_bindir}/supybot-test
%python_clone -a %{buildroot}%{_bindir}/supybot-wizard

%check
%{python_expand export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}%{$python_sitelib}/
%python_exec test/test.py
}

%post
%{python_install_alternative supybot supybot-adduser supybot-botchk
  supybot-plugin-create supybot-plugin-doc supybot-reset-password supybot-test supybot-wizard
  supybot.1 supybot-adduser.1 supybot-botchk.1 supybot-plugin-create.1
  supybot-plugin-doc.1 supybot-test.1 supybot-wizard.1
}

%postun
%{python_uninstall_alternative supybot}

%files %{python_files}
%doc README.md CONTRIBUTING.md
%license LICENSE.md
%python_alternative %{_bindir}/supybot
%python_alternative %{_bindir}/supybot-adduser
%python_alternative %{_bindir}/supybot-botchk
%python_alternative %{_bindir}/supybot-plugin-create
%python_alternative %{_bindir}/supybot-plugin-doc
%python_alternative %{_bindir}/supybot-reset-password
%python_alternative %{_bindir}/supybot-test
%python_alternative %{_bindir}/supybot-wizard
%{python_sitelib}/supybot/
%{python_sitelib}/limnoria-*.egg-info
%python_alternative %{_mandir}/man1/supybot.1
%python_alternative %{_mandir}/man1/supybot-adduser.1
%python_alternative %{_mandir}/man1/supybot-botchk.1
%python_alternative %{_mandir}/man1/supybot-plugin-create.1
%python_alternative %{_mandir}/man1/supybot-plugin-doc.1
%python_alternative %{_mandir}/man1/supybot-test.1
%python_alternative %{_mandir}/man1/supybot-wizard.1

%changelog
* Sat May  9 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-05-01:
  * Fix extra arguments to irc.reply() being ignored by messages
    returned by '@more' (gh#ProgVal/Limnoria#1405).
- Run an extra sed during %%setup to clean hashbang from a file not
  installed in an executable path.
- Drop the _service file, use full source URL directly allowing
  renaming of the tarball in %%{name}-%%{version} format.
* Fri Mar 27 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-03-19:
  * Update links to the documentation.
  * Updated translations.
- Use %%{name}-%%{version} naming scheme for source tarball.
* Mon Feb 10 2020 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2020-01-31:
  + RSS: If ids are missing, use <link> as id.
  + RSS: Show a meaningful error in case '@rss' is called with a non-URL/…
  + ChannelStats: Use the safe math evaluator.
  + core/Math: Move the math evaluator to src/utils/.
  + Math: Fix log/log10 return type.
  + Aka, Google, String: fix more DeprecationWarning in tests (#1328)
  + AutoMode, Channel, Nickometer: fix invalid escape sequence Deprecatio…
  + plugins: use r'' strings to fix DeprecationWarning in test cases (#1328)
  + Aka, Debug: cleanup imports
  + Use importlib instead of imp.
  + Replace failUnless/failIf with assertTrue/assertFalse.
  + Socket: Don't add instances twice in cls._instances.
  + Socket: use a proper lock instead of a boolean.
  + Add subcommand dispatching for CAP/FAIL/WARN/NOTE.
  + Rename doAuthenticate* functions to not conflict with callback names.
  + Make irc.error do nothing is no string is given as argument.
  + Call super().setValue() before defaultHttpHeaders.
  + Deduplicate setting Accept-Language HTTP header.
  + Web: Implement protocols.http.requestLanguage
  + Add supybot.protocols.http.requestLanguage
  + Fix getSpecific usage
  + Import MutableMapping and MutableSet from collections.abc.
  + setup.py: migrate shebang to Python 3
  + setup.py: remove obsolete version_info conditionals
  + scripts: remove obsolete conditionals for Python 2
  + scripts: migrate shebangs and version checks to Python 3
  + Be less hostile to users in --allow-root help
  + Readd Limnoria name to default part & quit messages
  + SedRegex: skip testReDoSTimeout if multiprocessing is disabled
  + SedRegex: update plugin metadata
  + SedRegex: spawn a single process to handle the whole history.
  + SedRegex: add test for ReDoS timeout
  + SedRegex: abort when a search times out
  + SedRegex: test case normalization of channel names
  + SedRegex: match channel names case insensitively
  + SedRegex: log all errors, always display the not found mesage
  + SedRegex: reuse processTimeout in the sub() process too
  + SedRegex: README: specifically mention that /s is specific to this plugin
  + SedRegex: make the regexp process timeout configurable
  + SedRegex: remove compatibility workaround for Python 2.7.6 and lower
  + SedRegex: skip testBoldReplacement on Python 2
  + SedRegex: remove a duplicate test
  + SedRegex: use self.__class__ instead of __class__ in tests (Python 2 …
  + SedRegex: add a bunch of test cases
  + SedRegex: bump copyright year to 2017
  + SedRegex: fix some replacement queries not working
  + SedRegex: also catch errors in the regexp_wrapper() step
  + SedRegex: log the exact error name instead of "SedRegex error"
  + SedRegex: require ending delimiter to prevent overzealous matching of…
  + SedRegex: work around "nothing to replace" errors on < Python 2.7.6 a…
  + SedRegex: fix flag matching
  + SedRegex: add configuration / usage instructions
  + SedRegex: implement 's' regex flag to only match the caller's message
  + SedRegex: allow free form flags and return them in _unpack_sed()
  + SedRegex: sanitize against \n\r\t in output
  + SedRegex: only operate on messages from the current network
  + SedRegex: work around "nothing to repeat" errors on Python < 2.7.6
* Sat Jan  4 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2020-01-01:
  + Skip irctest when optional dependencies are not installed.
- python2 no longer supported; use skip_python2 macro to disable
  it.
* Mon Dec 30 2019 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2019-12-21:
  + Add config supybot.reply.format.list.maximumItems to limit the size o…
  + Add fallback if getting supybot.language from registry cache failed.
  + All plugins: set Limnoria contributors as maintainer
  + Better formatting in supybot.Author if some fields are missing
  + Get locale name on startup from registry cache instead of parsing con…
  + Make getLocaleFromRegistryCache reload existing locales.
  + Math: Fix test on Pypy.
  + Math: Display a nicer error in case of MemoryError.
  + MoobotFactoids: Fix support of commands sent in private.
  + Nicer error message in getChannel/makeChannelFilename when channel is…
  + Plugin: support showing __maintainer__ field in the 'author' command
  + Plugin: accept author name in 'contributors' command
  + QuoteGrabs: fix SyntaxWarning (#1391)
  + Remove dead code from Group that belongs in Value.
  + Request msgid capability.
  + RSS: Register feed config in config.py instead of plugin.py.
  + Scheduler: Use assertRegexp instead of assertNotRegexp in tests.
  + Scheduler: Use default timeout for assertResponse.
  + Scheduler: Use mocking to make tests faster.
  + Services: Fix typo in doInvite() (#1394)
  + Update core fr translation.
  + Update supybot-plugin-doc to work with current version of the registry.
  + Web: Lower log level when title could not be found.
  + Web: Remove leading space if the prefix is empty.
  + Web: Add early returns on exception when snarfing titles.
  + src/callbacks.py: use network-specific values.
  + test: Don't overwrite the main Schedule in the driver list.
  + test: Mock calls to time.sleep()
  + test: choose a random free port for tests using the HTTP server
* Sun Nov 17 2019 Lars Vogdt <lars@linux-schulserver.de>
- Update to version 2019-11-09:
  + Fix log on SASL failure.
  + Math: Rewrite calc functions with a proper evaluator.
  + Log SASL mechanism on failure. Closes GH-1014.
  + Config: Add : prefix to network-specific values listed by 'config list'.
  + Web: Catch more errors in getTitle.
  + Split 'CAP REQ' commands to not exceed 512 bytes.
  + Reset capability set state on reconnection.
  + Fix conditional on CTCP in urlSnarfer
  + Use a real invalid email in supybot.authors.unknown
  + Don't repeat nick in supybot.Author if nick and name are the same
  + regexp_wrapper: return None instead of False when search times out
* Wed Sep 11 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2019-09-08:
  * Interpret empty server tag values as missing tag values. As
    required by https://ircv3.net/specs/extensions/message-tags
- Changes from version 2019-08-25:
  * Config: Prevent accidental leak of private values on public
    channels.
- Changes from version 2019-07-17:
  * Google: Update for Google's new HTML layout.
* Tue Mar 19 2019 Atri B <badshah400@gmail.com>
- Update to version 2019-02-23:
  * Revert changes to the structure of sdist packages.
  * Fix bugs in wrapping IRC messages.
  * Support for (future) Python 3.8.
  * Fix encoding issue on Python 2.
  * Support [ipv6]:port format.
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 2018-09-10:
  * Fix Python 3.7 support.
* Tue Aug 28 2018 BArendartchuk@suse.com
- enable Python 2 binaries with update-alternatives: they are
  needed for running legacy plugins
* Fri Aug 17 2018 tchvatal@suse.com
- Drop -devel from deps
* Thu Aug 16 2018 badshah400@gmail.com
- Update to version 2018-06-25-2:
  * test_plugin_create: skip if supybot-plugin-create is not
    installed.
- Changes from version 2018-06-25:
  * Fixes and tests to supybot-plugin-create; modernize the plugin
    template (gh#ProgVal/Limnoria#1340)
  * supybot-plugin-create: compactify import statements in the
    template
  * supybot-plugin-create: prefer importlib over imp on Python >=
    3.4
  * test: add test cases for supybot-plugin-create
  * -plugin-create: fix errors when only a subset of args are
    given
  * -plugin-create: rename --real-name to --author/-a
  * -plugin-create: add -d as an alias to --desc for consistency
* Thu May 10 2018 toddrme2178@gmail.com
- Avoid problem with bytecode being overwritten by tests
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2018-04-21:
  * Do not break UTF-8 characters in long words. Closes
    gh#ProgVal/Limnoria#1333.
* Wed Apr 18 2018 badshah400@gmail.com
- The gnupg python module is called python{2,3}-python-gnupg,
  adapt Requires accordingly.
* Fri Apr 13 2018 badshah400@gmail.com
- Switch to using PySocks instead of SocksiPy: the former is
  well-maintained than the latter.
* Sat Mar 31 2018 jengelh@inai.de
- Remove empty filler marketing wording from description.
* Wed Feb 21 2018 badshah400@gmail.com
- Enable python2 module [not binaries] since we have
  python2-SocksiPy now.
* Thu Feb 15 2018 badshah400@gmail.com
- Update to master-2018-01-28:
  * NickAuth: Fix NameError caused by e732931.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to master-2017-10-25:
  * Aka: Escape the command in help strings, so they can be
    copy-pasted into @aka add.
- Convert to python single-spec; disable python2 modules as
  python2-SocksiPy is not available.
- Enable tests as part of %%%%check.
* Fri Nov 25 2016 badshah400@gmail.com
- Initial package.
